@@ -1,6 +1,6 @@
 /*
 
-    $Id: kmahjongg.cpp,v 1.56 2001/01/14 13:24:09 davidb Exp $
+    $Id: kmahjongg.cpp,v 1.58 2001/04/25 13:50:38 kaper Exp $
 
     kmahjongg, the classic mahjongg game for KDE project
 
@@ -28,7 +28,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include <qmsgbox.h>
+#include <qmessagebox.h>
 #include <qtimer.h>
 #include <qaccel.h>
 #include <qfile.h>
@@ -386,6 +386,7 @@ void KMahjonggWidget::setupMenuBar()
 
   KPopupMenu *game = new KPopupMenu;
   game->insertItem( i18n("&Help me"),           ID_GAME_HELP );
+  game->setAccel(Key_H, ID_GAME_HELP);
   game->insertItem( SmallIcon("reload"), i18n("Shu&ffle"),           ID_GAME_SHUFFLE );
   game->insertItem( i18n("&Demo mode"),         ID_GAME_DEMO );
   game->insertItem( i18n("Show &matching tiles"), ID_GAME_SHOW );
